#!/usr/bin/env node
'use strict';

require('colors');
require('shelljs/global');

const path = require('path');
const argv = require('minimist')(process.argv.slice(2));

const basename = argv._[0] || '';
const destDir = path.join(process.cwd(), basename);
const srcFiles = ['index.js', 'package.json', 'readme.md', 'layouts', 'src'];

const help = `
Usage:
  metalwork [dir]
  -h, --help            Display this information

Scaffold out a basic Metalwork site into new directory.`;

const noPathProvided = `
ERROR: Provide a [path] argument:
$ metalwork new-site`.red;

const gettingStarted = `
Getting started:
  $ cd ${basename}
  $ npm start`.green;

function build (src, dest) {
  mkdir('-p', dest);
  cp('-r', src.map(file => path.join(__dirname, file)), dest);
  echo(`Built new Metalwork site in ${destDir}.`.green);
  cd(destDir);
  echo('Installing dependencies...'.green);
  exec('npm install', {silent: true});
  echo('Done.'.bold.green);
  cd(process.cwd());
  echo(gettingStarted);
}

/**
 * Entry Point
 */
if (argv.h || argv.help) {
  echo(help);
} else if (!basename) {
  echo(noPathProvided);
} else {
  build(srcFiles, destDir);
}

